@@ -48,6 +48,7 @@ from .known_folders import (
     GALContacts,
     GraphAnalytics,
     IMContactList,
+    ImplicitContacts,
     Inbox,
     Inference,
     Journal,
@@ -100,6 +101,7 @@ from .known_folders import (
     SkypeTeamsMessages,
     SmsAndChatsSync,
     SpoolerQueue,
+    SubstrateContacts,
     SwssItems,
     SyncIssues,
     System,
@@ -172,6 +174,7 @@ __all__ = [
     "GraphAnalytics",
     "IMContactList",
     "Inbox",
+    "ImplicitContacts",
     "Inference",
     "Journal",
     "JunkEmail",
@@ -230,6 +233,7 @@ __all__ = [
     "SkypeTeamsMessages",
     "SmsAndChatsSync",
     "SpoolerQueue",
+    "SubstrateContacts",
     "SwssItems",
     "SyncIssues",
     "System",
