@@ -76,66 +76,72 @@ ITEM_CLASSES = (
     PostItem,
     Task,
 )
+TASK_ITEM_CLASSES = (Task,)
+CONTACT_ITEM_CLASSES = (Contact, DistributionList)
+MESSAGE_ITEM_CLASSES = (Message, MeetingRequest, MeetingResponse, MeetingCancellation)
 
 __all__ = [
-    "RegisterMixIn",
-    "MESSAGE_DISPOSITION_CHOICES",
-    "SAVE_ONLY",
-    "SEND_ONLY",
-    "SEND_AND_SAVE_COPY",
-    "CalendarItem",
-    "AcceptItem",
-    "TentativelyAcceptItem",
-    "DeclineItem",
-    "CancelCalendarItem",
-    "MeetingRequest",
-    "MeetingResponse",
-    "MeetingCancellation",
-    "CONFERENCE_TYPES",
-    "Contact",
-    "Persona",
-    "DistributionList",
-    "SEND_MEETING_INVITATIONS_CHOICES",
-    "SEND_TO_NONE",
-    "SEND_ONLY_TO_ALL",
-    "SEND_TO_ALL_AND_SAVE_COPY",
-    "SEND_MEETING_INVITATIONS_AND_CANCELLATIONS_CHOICES",
-    "SEND_ONLY_TO_CHANGED",
-    "SEND_TO_CHANGED_AND_SAVE_COPY",
-    "SEND_MEETING_CANCELLATIONS_CHOICES",
-    "AFFECTED_TASK_OCCURRENCES_CHOICES",
-    "ALL_OCCURRENCES",
-    "SPECIFIED_OCCURRENCE_ONLY",
-    "CONFLICT_RESOLUTION_CHOICES",
-    "NEVER_OVERWRITE",
-    "AUTO_RESOLVE",
-    "ALWAYS_OVERWRITE",
-    "DELETE_TYPE_CHOICES",
-    "HARD_DELETE",
-    "SOFT_DELETE",
-    "MOVE_TO_DELETED_ITEMS",
-    "BaseItem",
-    "Item",
-    "BulkCreateResult",
-    "Message",
-    "ReplyToItem",
-    "ReplyAllToItem",
-    "ForwardItem",
-    "PostItem",
-    "PostReplyItem",
-    "Task",
-    "ITEM_TRAVERSAL_CHOICES",
-    "SHALLOW",
-    "SOFT_DELETED",
-    "ASSOCIATED",
-    "SHAPE_CHOICES",
-    "ID_ONLY",
-    "DEFAULT",
-    "ALL_PROPERTIES",
-    "SEARCH_SCOPE_CHOICES",
     "ACTIVE_DIRECTORY",
     "ACTIVE_DIRECTORY_CONTACTS",
+    "AFFECTED_TASK_OCCURRENCES_CHOICES",
+    "ALL_OCCURRENCES",
+    "ALL_PROPERTIES",
+    "ALWAYS_OVERWRITE",
+    "ASSOCIATED",
+    "AUTO_RESOLVE",
+    "AcceptItem",
+    "BaseItem",
+    "BulkCreateResult",
+    "CONFERENCE_TYPES",
+    "CONFLICT_RESOLUTION_CHOICES",
+    "CONTACT_ITEM_CLASSES",
     "CONTACTS",
     "CONTACTS_ACTIVE_DIRECTORY",
+    "CalendarItem",
+    "CancelCalendarItem",
+    "Contact",
+    "DEFAULT",
+    "DELETE_TYPE_CHOICES",
+    "DeclineItem",
+    "DistributionList",
+    "ForwardItem",
+    "HARD_DELETE",
+    "ID_ONLY",
     "ITEM_CLASSES",
+    "ITEM_TRAVERSAL_CHOICES",
+    "Item",
+    "MESSAGE_DISPOSITION_CHOICES",
+    "MESSAGE_ITEM_CLASSES",
+    "MOVE_TO_DELETED_ITEMS",
+    "TASK_ITEM_CLASSES",
+    "MeetingCancellation",
+    "MeetingRequest",
+    "MeetingResponse",
+    "Message",
+    "NEVER_OVERWRITE",
+    "Persona",
+    "PostItem",
+    "PostReplyItem",
+    "RegisterMixIn",
+    "ReplyAllToItem",
+    "ReplyToItem",
+    "SAVE_ONLY",
+    "SEARCH_SCOPE_CHOICES",
+    "SEND_AND_SAVE_COPY",
+    "SEND_MEETING_CANCELLATIONS_CHOICES",
+    "SEND_MEETING_INVITATIONS_AND_CANCELLATIONS_CHOICES",
+    "SEND_MEETING_INVITATIONS_CHOICES",
+    "SEND_ONLY",
+    "SEND_ONLY_TO_ALL",
+    "SEND_ONLY_TO_CHANGED",
+    "SEND_TO_ALL_AND_SAVE_COPY",
+    "SEND_TO_CHANGED_AND_SAVE_COPY",
+    "SEND_TO_NONE",
+    "SHALLOW",
+    "SHAPE_CHOICES",
+    "SOFT_DELETE",
+    "SOFT_DELETED",
+    "SPECIFIED_OCCURRENCE_ONLY",
+    "Task",
+    "TentativelyAcceptItem",
 ]
