@@ -121,7 +121,7 @@ class Message(Item):
 
     @require_id
     def create_reply(self, subject, body, to_recipients=None, cc_recipients=None, bcc_recipients=None, author=None):
-        if to_recipients is None:
+        if not to_recipients:
             if not self.author:
                 raise ValueError("'to_recipients' must be set when message has no 'author'")
             to_recipients = [self.author]
@@ -141,17 +141,23 @@ class Message(Item):
 
     @require_id
     def create_reply_all(self, subject, body, author=None):
-        to_recipients = list(self.to_recipients) if self.to_recipients else []
+        me = MailboxField().clean(self.account.primary_smtp_address.lower())
+        to_recipients = set(self.to_recipients or [])
+        to_recipients.discard(me)
+        cc_recipients = set(self.cc_recipients or [])
+        cc_recipients.discard(me)
+        bcc_recipients = set(self.bcc_recipients or [])
+        bcc_recipients.discard(me)
         if self.author:
-            to_recipients.append(self.author)
+            to_recipients.add(self.author)
         return ReplyAllToItem(
             account=self.account,
             reference_item_id=ReferenceItemId(id=self.id, changekey=self.changekey),
             subject=subject,
             new_body=body,
-            to_recipients=to_recipients,
-            cc_recipients=self.cc_recipients,
-            bcc_recipients=self.bcc_recipients,
+            to_recipients=list(to_recipients),
+            cc_recipients=list(cc_recipients),
+            bcc_recipients=list(bcc_recipients),
             author=author,
         )
 
