@@ -5,13 +5,9 @@ import copy
 import datetime
 import logging
 import time
+import zoneinfo
 from pathlib import Path
 
-try:
-    import zoneinfo
-except ImportError:
-    from backports import zoneinfo
-
 from yaml import safe_load
 
 from exchangelib import DELEGATE, Account, CalendarItem, Configuration, Credentials, FaultTolerance
