@@ -39,7 +39,10 @@ class EWSDateTimeTest(TimedTestCase):
         self.assertEqual(dt.tzinfo.ms_id, tz.ms_id)
         self.assertEqual(dt.tzinfo.ms_name, tz.ms_name)
         self.assertEqual(str(dt), "2000-01-02 03:04:05.678901+05:00")
-        self.assertEqual(repr(dt), "EWSDateTime(2000, 1, 2, 3, 4, 5, 678901, tzinfo=EWSTimeZone(key='Etc/GMT-5'))")
+        self.assertEqual(
+            repr(dt).replace("exchangelib.ewsdatetime.EWSTimeZone", "EWSTimeZone"),
+            "EWSDateTime(2000, 1, 2, 3, 4, 5, 678901, tzinfo=EWSTimeZone(key='Etc/GMT-5'))",
+        )
 
         # Test a DST timezone
         tz = EWSTimeZone("Europe/Copenhagen")
@@ -50,7 +53,8 @@ class EWSDateTimeTest(TimedTestCase):
         self.assertEqual(dt.tzinfo.ms_name, tz.ms_name)
         self.assertEqual(str(dt), "2000-01-02 03:04:05.678901+01:00")
         self.assertEqual(
-            repr(dt), "EWSDateTime(2000, 1, 2, 3, 4, 5, 678901, tzinfo=EWSTimeZone(key='Europe/Copenhagen'))"
+            repr(dt).replace("exchangelib.ewsdatetime.EWSTimeZone", "EWSTimeZone"),
+            "EWSDateTime(2000, 1, 2, 3, 4, 5, 678901, tzinfo=EWSTimeZone(key='Europe/Copenhagen'))",
         )
 
         # Test from_string
@@ -222,26 +226,9 @@ class EWSTimeZoneTest(TimedTestCase):
         # Test IANA exceptions. This fails if available_timezones() returns timezones that we have not yet implemented.
         # If this fails in CI but not locally, you need to update the 'tzdata' package to the latest version.
         sanitized = list(t for t in zoneinfo.available_timezones() if not t.startswith("SystemV/") and t != "localtime")
-        # TODO: IANA removed timezones that zoneinfo still has
         self.assertEqual(
             set(sanitized) - set(EWSTimeZone.IANA_TO_MS_MAP),
-            {
-                "America/Montreal",
-                "America/Nipigon",
-                "America/Pangnirtung",
-                "America/Rainy_River",
-                "America/Santa_Isabel",
-                "America/Thunder_Bay",
-                "America/Yellowknife",
-                "Australia/Currie",
-                "CST6CDT",
-                "EST5EDT",
-                "Europe/Uzhgorod",
-                "Europe/Zaporozhye",
-                "MST7MDT",
-                "PST8PDT",
-                "Pacific/Johnston",
-            },
+            set(),
         )
 
     @requests_mock.mock()
