@@ -57,6 +57,7 @@ from exchangelib.folders import (
     GALContacts,
     GraphAnalytics,
     IMContactList,
+    ImplicitContacts,
     Inbox,
     Journal,
     JunkEmail,
@@ -86,6 +87,7 @@ from exchangelib.folders import (
     SingleFolderQuerySet,
     SkypeTeamsMessages,
     SmsAndChatsSync,
+    SubstrateContacts,
     SwssItems,
     SyncIssues,
     Tasks,
@@ -517,9 +519,9 @@ class FolderTest(EWSTest):
         for f in self.account.root.walk():
             with self.subTest(f=f):
                 if f.is_distinguished:
-                    self.assertIsNotNone(f.DISTINGUISHED_FOLDER_ID)
+                    self.assertIsNotNone(f.DISTINGUISHED_FOLDER_ID, f)
                 else:
-                    self.assertIsNone(f.DISTINGUISHED_FOLDER_ID)
+                    self.assertIsNone(f.DISTINGUISHED_FOLDER_ID, f)
             with self.subTest(f=f):
                 if isinstance(
                     f,
@@ -579,7 +581,7 @@ class FolderTest(EWSTest):
                     self.assertEqual(f.folder_class, "IPF.Contact.MOC.ImContactList")
                 elif isinstance(f, QuickContacts):
                     self.assertEqual(f.folder_class, "IPF.Contact.MOC.QuickContacts")
-                elif isinstance(f, (Contacts, ExternalContacts)):
+                elif isinstance(f, (Contacts, ExternalContacts, ImplicitContacts, SubstrateContacts)):
                     self.assertEqual(f.folder_class, "IPF.Contact")
                 elif isinstance(f, Birthdays):
                     self.assertEqual(f.folder_class, "IPF.Appointment.Birthday")
@@ -1011,7 +1013,7 @@ class FolderTest(EWSTest):
         for f in self.account.root.walk():
             with self.subTest(item=f):
                 if f.__class__ in NON_DELETABLE_FOLDERS + WELLKNOWN_FOLDERS_IN_ARCHIVE_ROOT + WELLKNOWN_FOLDERS_IN_ROOT:
-                    self.assertEqual(f.is_deletable, False)
+                    self.assertEqual(f.is_deletable, False, f)
                     try:
                         f.delete()
                     except (ErrorDeleteDistinguishedFolder, ErrorCannotDeleteObject, ErrorItemNotFound):
