@@ -1,9 +1,8 @@
 # coding=utf-8
 from collections import namedtuple
 
-from exchangelib.folders import FolderCollection
-from exchangelib.folders import Inbox
-from exchangelib.queryset import QuerySet, Q
+from exchangelib.folders import FolderCollection, Inbox
+from exchangelib.queryset import Q, QuerySet
 
 from .common import TimedTestCase
 
@@ -11,25 +10,23 @@ from .common import TimedTestCase
 class QuerySetTest(TimedTestCase):
     def test_magic(self):
         self.assertEqual(
-            str(
-                QuerySet(folder_collection=FolderCollection(account=None, folders=[Inbox(root='XXX', name='FooBox')]))
-            ),
-            'QuerySet(q=Q(), folders=[Inbox (FooBox)])'
+            str(QuerySet(folder_collection=FolderCollection(account=None, folders=[Inbox(root="XXX", name="FooBox")]))),
+            "QuerySet(q=Q(), folders=[Inbox (FooBox)])",
         )
 
     def test_from_folder(self):
-        MockRoot = namedtuple('Root', ['account'])
-        folder = Inbox(root=MockRoot(account='XXX'))
+        MockRoot = namedtuple("Root", ["account"])
+        folder = Inbox(root=MockRoot(account="XXX"))
         self.assertIsInstance(folder.all(), QuerySet)
         self.assertIsInstance(folder.none(), QuerySet)
-        self.assertIsInstance(folder.filter(subject='foo'), QuerySet)
-        self.assertIsInstance(folder.exclude(subject='foo'), QuerySet)
+        self.assertIsInstance(folder.filter(subject="foo"), QuerySet)
+        self.assertIsInstance(folder.exclude(subject="foo"), QuerySet)
 
     def test_queryset_copy(self):
-        qs = QuerySet(folder_collection=FolderCollection(account=None, folders=[Inbox(root='XXX')]))
+        qs = QuerySet(folder_collection=FolderCollection(account=None, folders=[Inbox(root="XXX")]))
         qs.q = Q()
-        qs.only_fields = ('a', 'b')
-        qs.order_fields = ('c', 'd')
+        qs.only_fields = ("a", "b")
+        qs.order_fields = ("c", "d")
         qs.return_format = QuerySet.NONE
 
         # Initially, immutable items have the same id()
@@ -47,8 +44,8 @@ class QuerySetTest(TimedTestCase):
 
         # Set the same values, forcing a new id()
         new_qs.q = Q()
-        new_qs.only_fields = ('a', 'b')
-        new_qs.order_fields = ('c', 'd')
+        new_qs.only_fields = ("a", "b")
+        new_qs.order_fields = ("c", "d")
         new_qs.return_format = QuerySet.NONE
 
         self.assertNotEqual(id(qs), id(new_qs))
@@ -61,8 +58,8 @@ class QuerySetTest(TimedTestCase):
 
         # Set the new values, forcing a new id()
         new_qs.q = Q(foo=5)
-        new_qs.only_fields = ('c', 'd')
-        new_qs.order_fields = ('e', 'f')
+        new_qs.only_fields = ("c", "d")
+        new_qs.order_fields = ("e", "f")
         new_qs.return_format = QuerySet.VALUES
 
         self.assertNotEqual(id(qs), id(new_qs))
